BarcodeValidation enum

Mode of barcode validation.

Currently only PDF417 barcodes are supported.

Inheritance
Available extensions

Values

none → const BarcodeValidation

Barcode presence is not required.

requireValidityIfPresent → const BarcodeValidation

If a barcode is present, it must be valid.

This does not guarantee a readable barcode in the result image. A heavily blurred barcode cannot be located at all.

If you want to use this option, you will need the IDV Document Barcode module to be active.

requirePresenceAndValidity → const BarcodeValidation

A barcode must be present and valid.

If you want to use this option, you will need the IDV Document Barcode module to be active.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BarcodeValidation>
A constant List of the values in this enum, in order of their declaration.