minSharpness property
Minimum sharpness.
Value in interval [0.0, 1.0].
Throws an ArgumentError if the value is out of the interval.
Implementation
final double? minSharpness;
Minimum sharpness.
Value in interval [0.0, 1.0].
Throws an ArgumentError if the value is out of the interval.
final double? minSharpness;