Td1MachineReadableZone class final

Annotations

Properties

compositeCheckDigit CheckDigit
Composite check digit validity flag.
final
dateOfBirth DateElementWithCheckDigit
Date of birth.
final
dateOfExpiry DateElementWithCheckDigit
Date of expiry.
final
documentCode Element
Document code.
final
documentNumber ElementWithCheckDigit
Document Number.
final
hashCode int
The hash code for this object.
no setterinherited
issuingStateOrOrganization Element
Issuing State or organization.
final
name NameElement
Name.
final
nationality Element
Nationality.
final
optionalData List<Element>
Optional data elements.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sex Element
Sex.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited