dot_document library
IDV Document plugin.
Classes
- AutoCaptureConfiguration
- Configuration for auto capture components.
- Barcode
- Barcode located in the image.
- BarcodeDetectionPosition
- Position of the barcode in the image.
- BaseDocumentAutoCaptureWidgetConfiguration
- Base configuration for the UI Document Auto Capture component (DocumentAutoCaptureWidget).
- CameraConfiguration
- Configuration for components utilizing a camera.
- CheckDigit
- A check digit belonging to a particular Machine Readable Zone element with a checksum in the MRZ.
- CommonConfiguration
- Common configuration for all components.
- Date
- Parsed date value in Machine Readable Zone.
- DateElementWithCheckDigit
- Date element of Machine Readable Zone with checksum.
- DetectionPosition
- Position of the document card in the image.
- DocumentAutoCaptureDetection
- Document detection in Document Auto Capture UI component.
- DocumentAutoCaptureResult
- Result of the Document Auto Capture UI component.
- DocumentAutoCaptureWidget
- Document Auto Capture UI component (widget).
- DocumentAutoCaptureWidgetConfiguration
- Configuration for the UI Document Auto Capture component (DocumentAutoCaptureWidget).
- DocumentAutoCaptureWidgetController
- Controller for managing the Document Auto Capture process.
- DocumentDetectorDocument
- Result of the document detection process.
- DocumentImageQuality
- Document image quality.
- DocumentModules
- Container for document library module configurations.
- DocumentQuality
- Document quality.
- DotDocumentBarcodeModuleConfiguration
- Document barcode module configuration.
- DotDocumentLibraryConfiguration
- Document library configuration.
- DotSdk
- IDV SDK main component for initialization and deinitialization.
- DotSdkConfiguration
- Configuration for the main IDV SDK component (DotSdk).
- Element
- Element of Machine Readable Zone.
- ElementWithCheckDigit
- Element of Machine Readable Zone with checksum.
- HiddenPlaceholder
- Hidden placeholder.
- IdleUiState
- Idle state.
- Image
- Represents an image.
- ImageFactory
- A factory class for creating ui.Image objects.
- ImageSize
- Represents image size in pixels.
- InitializingUiState
- Initializing state.
- IntervalDouble
- Representation of closed interval with value type double.
- IosCameraPreviewStyle
- Style of the camera preview in the UI component.
- IosCandidateSelectionInstructionStyle
- Style of the instruction in the UI component with candidate selection.
- IosCandidateSelectionPlaceholderStyle
- Style of the placeholder in the UI component with candidate selection.
- IosDocumentAutoCaptureWidgetStyle
- Style for the UI Document Auto Capture component (DocumentAutoCaptureWidget).
- IosInstructionStyle
- Style of the instruction in the UI component.
- IosNamedUiFont
- Representation of iOS UIFont created by UIFont(name: String, size: CGFloat). You can use native iOS fonts or you can add custom font to the iOS project and use it.
- IosPlaceholderStyle
- Style of the placeholder in the UI component.
- IosSystemUiFont
- Representation of iOS system UIFont.
- IosUiFont
- Representation of iOS UIFont.
- Libraries
- Container for library configurations.
- MachineReadableZone
- Machine Readable Zone (MRZ). It contains a travel document type and the parsed content in one of the TD1, TD2 or TD3.
- NameElement
- Name element of Machine Readable Zone.
- Placeholder
- Placeholder.
- PointDouble
- Point in two-dimensional euclidean space.
- Preview
- Geometric properties of the preview. All rectangles are defined relative to the preview container.
- QualityAttributeThresholdPresets
- Pre-defined sets of thresholds for Document Auto Capture.
- QualityAttributeThresholds
- Thresholds of quality attributes.
- RectangleDouble
- Rectangle in two-dimensional euclidean space.
- RunningUiState
- Running state.
- StringPosition
- Position of the string in Machine Readable Zone.
- Td1MachineReadableZone
- Machine Readable Zone according to Doc 9303 Part 5: Specifications for TD1 Size Machine Readable Official Travel Documents (MROTDs).
- Td2MachineReadableZone
- Machine Readable Zone according to Doc 9303 Part 6: Specifications for TD2 Size Machine Readable Official Travel Documents (MROTDs).
- Td3MachineReadableZone
- Machine Readable Zone according to Doc 9303 Part 4: Specifications for Machine Readable Passports (MRPs) and other TD3 Size MRTDs.
- UiState
- UI state.
- VisiblePlaceholder
- Visible placeholder.
Enums
- BarcodeValidation
- Mode of barcode validation.
- CameraFacing
- Camera facing.
- CameraPreviewScaleType
- Camera preview scale type.
- ImageFormat
- Image format.
- IosUiFontWeight
- Representation of iOS UIFont.Weight.
- MrzValidation
- Mode of MRZ (Machine Readable Zone) validation.
- Phase
- Document auto capture process phase.
- PlaceholderType
- Type of placeholder.
- TravelDocumentType
- Travel document type according to ICAO Doc 9303.
- ValidationMode
- Validation mode.
Typedefs
- OnDocumentAutoCaptureCreatedCallback = void Function(DocumentAutoCaptureWidgetController controller)
- Called when the widget is created.
- OnDocumentAutoCaptureFinishedCallback = void Function(DocumentAutoCaptureResult result)
- Called only once for the whole process, when the final document image candidate has been chosen. Once this callback is called, the whole process is considered to be over.
- OnDocumentAutoCaptureNoCameraPermissionCallback = void Function()
- Called when camera permission was not granted.
- OnDocumentAutoCaptureUiStateUpdatedCallback = void Function(UiState uiState)
- Called when a camera image is processed.