DocumentModules class final
Container for document library module configurations.
- Annotations
Constructors
- DocumentModules({DotDocumentBarcodeModuleConfiguration? barcode})
-
Create an instance.
const
Properties
- barcode → DotDocumentBarcodeModuleConfiguration?
-
Document barcode module configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited