IosCandidateSelectionPlaceholderStyle class final
Style of the placeholder in the UI component with candidate selection.
DISCLAIMER: Only valid for iOS, it is ignored on Android.
- Annotations
Constructors
- IosCandidateSelectionPlaceholderStyle({IosPlaceholderStyle placeholderStyle = const IosPlaceholderStyle(), Color candidateSelectionColor = IosStyleDefaultColors.candidateSelectionGreen})
-
Create an instance.
const
Properties
- candidateSelectionColor → Color
-
Placeholder color during candidate selection. Default value is
IosStyleDefaultColors.candidateSelectionGreen.final - hashCode → int
-
The hash code for this object.
no setterinherited
- placeholderStyle → IosPlaceholderStyle
-
Placeholder style. Default value is IosPlaceholderStyle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited