IosDocumentAutoCaptureWidgetStyle class final
Style for the UI Document Auto Capture component (DocumentAutoCaptureWidget).
DISCLAIMER: Only valid for iOS, it is ignored on Android.
- Annotations
Constructors
- IosDocumentAutoCaptureWidgetStyle({IosCameraPreviewStyle cameraPreview = const IosCameraPreviewStyle(), IosCandidateSelectionInstructionStyle instruction = const IosCandidateSelectionInstructionStyle(), IosCandidateSelectionPlaceholderStyle placeholder = const IosCandidateSelectionPlaceholderStyle()})
-
Create an instance.
const
Properties
- cameraPreview → IosCameraPreviewStyle
-
Camera preview. Default value is IosCameraPreviewStyle.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instruction → IosCandidateSelectionInstructionStyle
-
Instruction. Default value is IosCandidateSelectionInstructionStyle.
final
- placeholder → IosCandidateSelectionPlaceholderStyle
-
Placeholder. Default value is IosCandidateSelectionPlaceholderStyle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited